==========================================================
``mosaik.simmanager`` --- Management of external processes
==========================================================

.. automodule:: mosaik.simmanager

.. autofunction:: start

.. autofunction:: start_inproc

.. autofunction:: start_proc

.. autofunction:: start_connect

.. autoclass:: SimProxy
   :members:

.. autoclass:: LocalProcess
   :members:

.. autoclass:: RemoteProcess
   :members:

.. autoclass:: MosaikRemote
   :members:
